@@ -156,6 +156,7 @@ static OtrgDialogWaitHandle otrg_gtk_dialog_private_key_wait_start(
     const char *protocol_print;
     GtkWidget *label;
     GtkWidget *dialog;
+    OtrgDialogWaitHandle handle;
 
     p = gaim_find_prpl(protocol);
     protocol_print = (p ? p->info->name : "Unknown");
@@ -166,7 +167,7 @@ static OtrgDialogWaitHandle otrg_gtk_dialog_private_key_wait_start(
 	
     dialog = create_dialog(GAIM_NOTIFY_MSG_INFO, title, primary, secondary,
 	    0, &label);
-    OtrgDialogWaitHandle handle = malloc(sizeof(struct s_OtrgDialogWait));
+    handle = malloc(sizeof(struct s_OtrgDialogWait));
     handle->dialog = dialog;
     handle->label = label;
 
