@@ -773,7 +773,7 @@ static void otrg_gtk_ui_config_buddy(GaimBuddy *buddy)
 
     if (!data) return;
 
-    dialog = gtk_dialog_new_with_buttons("OTR Options",
+    dialog = gtk_dialog_new_with_buttons("OTR Settings",
 					 NULL, 0,
 					 GTK_STOCK_OK, GTK_RESPONSE_OK,
 					 NULL);
@@ -792,7 +792,7 @@ static void otrg_gtk_ui_config_buddy(GaimBuddy *buddy)
     /* Set the title */
 
     label_text = g_strdup_printf("<span weight=\"bold\" size=\"larger\">"
-	    "OTR Options for %s</span>", gaim_buddy_get_contact_alias(buddy));
+	    "OTR Settings for %s</span>", gaim_buddy_get_contact_alias(buddy));
 
     label = gtk_label_new(NULL);
 
