@@ -388,6 +388,14 @@ static gboolean process_receiving_im(GaimAccount *account, char **who,
 
     free(username);
 
+    /* If we're supposed to ignore this incoming message (because it's a
+     * protocol message), set it to NULL, so that other plugins that
+     * catch receiving-im-msg don't return 0, and cause it to be
+     * displayed anyway. */
+    if (res) {
+	free(*message);
+	*message = NULL;
+    }
     return res;
 }
 
@@ -418,7 +426,7 @@ static void supply_extended_menu(GaimBlistNode *node, GList **menu)
 
     if (!GAIM_BLIST_NODE_IS_BUDDY(node)) return;
 
-     act = gaim_blist_node_action_new("OTR Options", otr_options_cb, NULL);
+     act = gaim_blist_node_action_new("OTR Settings", otr_options_cb, NULL);
      *menu = g_list_append(*menu, act);
 }
 
